@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: demoplugin.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: demoplugin.pm 41 2012-01-15 14:20:42Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 41 $
 
 # Demo plugin for NfSen
 
@@ -113,23 +113,8 @@ sub run {
 	my $netflow_sources = "$PROFILEDIR/$profilepath/$all_sources";
 
 	syslog('debug', "demoplugin args: '$netflow_sources'");
-	return;
 
-	# 
-	# process all sources of this profile at once
-	my @output = `$nfdump -M $netflow_sources -r nfcapd.$timeslot '$nf_filter'`;
-	
-	#
-    # Process the output and notify the duty team
-    my ($matched) = $output[-4] =~ /Summary: total flows: (\d+)/;
-
-    if ( defined $matched ) {
-        syslog('debug', "demoplugin run: $matched aggregated flows");
-    } else {
-        syslog('err', "demoplugin: Unparsable output line '$output[-4]'");
-    }
-
-}
+} # End of run
 
 #
 # Alert condition function.
