@@ -6,7 +6,7 @@ $Cond_ops = array ( 'and', 'or' );
 
 $SumStat_type_options = array ( 
 	'Total flows', 	 'Total packets', 	 'Total bytes',
-	'Flows/s', 'Packages/s', 'bits/s'
+	'flows/s', 'packets/s', 'bits/s'
 );
 
 $SumStat_comp = array ( '&gt;', '&lt;', 'outside' );
@@ -75,9 +75,7 @@ function alert_name_check(&$new_alert, $opts ) {
 
 function subject_validate (&$subject, $opts) {
 
-	if (!get_magic_quotes_gpc()) {
-   		$subject = addslashes($subject);
-	} 
+	$subject = addslashes($subject);
 	return 0;
 
 } // End of subject_validate
@@ -114,8 +112,7 @@ function check_email_address(&$emaillist, $opts) {
 	foreach ( explode(',',$emaillist) as $email ) {
 		$email = preg_replace("/^\s+/", '', $email);
 		$email = preg_replace("/\s+$/", '', $email);
-		// Just make a rough check of characters. the backend will check the email address format
-		if ( !ereg("^[A-Za-z0-9_\.@-]{6,128}$", $email) ) {
+		if ( filter_var($email, FILTER_VALIDATE_EMAIL) === false ) {
 			SetMessage('error', "Error illegal characters in email address '$email'");
 			return 1;
 		}
@@ -150,7 +147,7 @@ function DisplayFilterTable($alert, $readonly) {
 		</select>
 	</td>
 	<td>
-		<textarea name="filter" id="filter" multiline="true" wrap="phisical" rows="4" cols="70" 
+		<textarea name="filter" id="filter" multiline="true" wrap="physical" rows="4" cols="70" 
 			maxlength="10240" style="width:100%" <?php echo $disabled?>><?php
 			foreach ( $alert['filter'] as $line ) {
 				print htmlspecialchars(stripslashes($line)) . "\n";
