@@ -1,14 +1,11 @@
 <?php
 
-
 include "process.php";
 
 $DisplayOrder = array ( 'any', 'TCP', 'UDP', 'ICMP', 'other' );
 
 $TypeOrder	  = array ( 'flows', 'packets', 'traffic');
 
-
-
 /* 
  * scale factor: Number of  (cycletime) min slices per pixel
  * graph with 576 pixel
@@ -469,8 +466,8 @@ function Process_Details_tab ($tab_changed, $profile_changed) {
 		"DefaultFilter" => array( "required" => 0, 
 							  	  "default"  => -1,
 							  	  "allow_null" => 0,
-							  	  "match" => array_merge ( 
-										array(-1), array_keys($_SESSION['DefaultFilters'])),
+							  	  "match" => array_merge( array(-1),
+										array_key_exists('DefaultFilters', $_SESSION) ? $_SESSION['DefaultFilters'] : array()),
 							  	  "validate" => NULL),
 		"filter"		=> array( "required" => 0, 
 							  	  "default"  => array_key_exists('filter', $process_form) ? 
@@ -584,16 +581,10 @@ function Process_Details_tab ($tab_changed, $profile_changed) {
 							  	  "allow_null" => 1,
 							  	  "match" => "/^$|^[\s!-~]+$/",
 							  	  "validate" => NULL),
-		"fmt_save" 		=> array( "required" => 0, 
-							  	  "default"  => array_key_exists('fmt_save', $process_form) ?
-										$process_form['fmt_save'] : '',
-							  	  "allow_null" => 0,
-							  	  "match" => "/^$|^[A-Za-z0-9\.][A-Za-z0-9\-+_\/]+$/" , 
-							  	  "validate" => NULL),
-		"fmt_delete" 	=> array( "required" => 0, 
-							  	  "default"  => array_key_exists('fmt_delete', $process_form) ?
-										$process_form['fmt_delete'] : '',
-							  	  "allow_null" => 0,
+		"fmt_name" 		=> array( "required" => 0, 
+							  	  "default"  => array_key_exists('fmt_name', $process_form) ?
+										$process_form['fmt_name'] : '',
+							  	  "allow_null" => 1,
 							  	  "match" => "/^$|^[A-Za-z0-9\.][A-Za-z0-9\-+_\/]+$/" , 
 							  	  "validate" => NULL),
 		// stat type inputs
@@ -623,7 +614,7 @@ function Process_Details_tab ($tab_changed, $profile_changed) {
 							  	  "validate" => NULL),
 		"limitwhat" 	=> array( "required" => 0, 
 							  	  "default"  => array_key_exists('limitwhat', $process_form) ?
-										$process_form['limitwhat'] : '',
+										$process_form['limitwhat'] : 0,
 							  	  "allow_null" => 0,
 							  	  "match" => array( 0, 1),
 							  	  "validate" => NULL),
@@ -653,23 +644,23 @@ function Process_Details_tab ($tab_changed, $profile_changed) {
 		return;
 
 
-	if ( array_key_exists('fmt_save', $_POST) ) {
+		if ( array_key_exists('fmt_save_x', $_POST) && (array_key_exists('fmt_name', $_POST) && $_POST['fmt_name'] != '')) {
  		$cmd_opts['formatdef'] = $process_form['customfmt'];
-		$cmd_opts['format'] = $process_form['fmt_save'];
+		$cmd_opts['format'] = $process_form['fmt_name'];
 		$cmd_opts['overwrite'] = 1;
 		$cmd_out = nfsend_query("add-format", $cmd_opts, 0);
 		if ( is_array($cmd_out) ) {
 			unset($_SESSION['formatlist']);
-			$_SESSION['process_form']['output'] = $process_form['fmt_save'];
+			$_SESSION['process_form']['output'] = $process_form['fmt_name'];
 		}
 	} 
 
-	if ( array_key_exists('fmt_delete', $_POST) ) {
-		$_tmp = $_POST['fmt_delete'];
+	if ( array_key_exists('fmt_delete_x', $_POST) && (array_key_exists('fmt_name', $_POST) && $_POST['fmt_name'] != '') ) {
+		$_tmp = $_POST['fmt_name'];
 		if ( array_key_exists($_tmp, $OutputFormatOption)) {
 			SetMessage('error', "Can not delete built in format '$_tmp'");
 		} else if ( !array_key_exists($_tmp, $_SESSION['formatlist'])) {
-			SetMessage('error', "Unknon format '$_tmp'");
+			SetMessage('error', "Unknown format '$_tmp'");
 		} else {
 			$cmd_opts['format'] = $_tmp;
 			$cmd_out =  nfsend_query("delete-format", $cmd_opts, 0);
@@ -808,7 +799,7 @@ function DisplayDetails () {
 		print "</td>\n";
 	}
 	print "<td style='vertical-align: bottom;'>\n";
-	$str = strftime("%b %d %Y - %H:%M", $_SESSION['profileinfo']['tstart']);
+	$str = date('M d Y - H:i T', $_SESSION['profileinfo']['tstart']);
 
 	$expire = $_SESSION['profileinfo']['expire'];
 	if ( $expire == 0 ) {
@@ -847,9 +838,9 @@ function DisplayDetails () {
 	print "<tr><td>Type:</td><td>$type</td></tr>";
 	print "<tr><td>Max:</td><td>$maxsize</td></tr>";
 	print "<tr><td>Exp:</td><td>$expire</td></tr>";
-	print "<tr><td>Start:</td><td>$str $TZname</td></tr>\n";
-	$str = strftime("%b %d %Y - %H:%M", $_SESSION['profileinfo']['tend']);
-	print "<tr><td>End:</td><td>$str $TZname</td></tr>\n";
+	print "<tr><td>Start:</td><td>$str</td></tr>\n";
+	$str = date('M d Y - H:i T', $_SESSION['profileinfo']['tend']);
+	print "<tr><td>End:</td><td>$str</td></tr>\n";
 	print "</table>\n";
 
 	print "</td>\n";
@@ -1008,11 +999,13 @@ function DisplayDetails () {
 	</tr>
 	</table>
 <?php
+	$dateleft = date('M d Y - H:i T', $_SESSION['tleft']);
 	if ( $_SESSION['tleft'] == $_SESSION['tright'] ) {
-		$tslot = "timeslot " . strftime("%b %d %Y - %H:%M", $_SESSION['tleft']);
+		$tslot = "timeslot $dateleft";
 	} else {
-		$tslot = "timeslot " . strftime("%b %d %Y - %H:%M", $_SESSION['tleft']) . 
-			" - " . strftime("%b %d %Y - %H:%M", $_SESSION['tright']);
+	$datestr = date('M d Y - H:i T', $_SESSION['tleft']);
+		$dateright = date('M d Y - H:i T', $_SESSION['tright']);
+		$tslot = "timeslot $dateleft - $dateright";
 	}
 
 	$num_channels = count(array_keys($_SESSION['profileinfo']['channel']));
@@ -1151,7 +1144,7 @@ function DisplayDetails () {
 		foreach ( array( '', '_tcp', '_udp', '_icmp', '_other' ) as $_type ) {
 			if ( $statinfo ) {
 				$_val = ScaleValue($statinfo['flows' . $_type], $rateval);
-				$flows_sum[$_type] += $statinfo['flows' . $_type];
+				$flows_sum[$_type] += intval($statinfo['flows' . $_type]);
 			} else {
 				$_val = $mark_char;
 			}
@@ -1381,7 +1374,7 @@ function DisplayProcessing() {
 		<INPUT TYPE="button" NAME="JSbutton2" Value="All Sources" onClick="SelectAllSources()">
 	</TD>
 	<td style="vertical-align:top;">
-		<textarea name="filter" id="filter" multiline="true" wrap="phisical" rows="6" cols="50" maxlength="10240"><?php
+		<textarea name="filter" id="filter" multiline="true" wrap="physical" rows="6" cols="50" maxlength="10240"><?php
 			$display_filter = array_key_exists('editfilter', $process_form) ? $process_form['editfilter'] : $process_form['filter'];
 			foreach ( $display_filter as $line ) {
 				print htmlspecialchars(stripslashes($line)) . "\n";
@@ -1624,6 +1617,7 @@ function DisplayProcessing() {
 					<input type="image" name="fmt_save" id="fmt_save" title="Save format" 
 						onClick="SaveOutputFormat()" 
 						value="" src="icons/save.png">
+				  <input type="hidden" name="fmt_name" id="fmt_name" value="">
 					<input type="image" name="fmt_delete" id="fmt_delete" title="Delete format" 
 						onClick="DeleteOutputFormat()" 
 						value="" src="icons/trash.png" <?php echo $edit_display_style; ?>>
@@ -1725,7 +1719,7 @@ function DisplayProcessing() {
                                         	array_push($replacements, "$1  $hap_pic");
 					} else {
 						if ($ip_and_port_columns) { // matches cases when both ip and port are available but are located in separate columns
-							// ICMP verion
+							// ICMP version
 							$ip_and_port_pattern = "/(\s*)([^\s]+)(\s+)(0|\d\.\d)/";
 							$ip_and_port_replacement = "$1$2$3$4 " .
 								"<a href=\"nfsen.php?tab=5&sub_tab=" . $hap4nfsen_id . "&ip=$2&mode=new\" title='HAP graphlet for $2'>$hap_pic</a>";
