@@ -1,6 +1,6 @@
 <?php
 /*
- *
+ *  Copyright (c) 2022 Peter Haag
  *  Copyright (c) 2004, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
  *  All rights reserved.
  *
@@ -28,25 +28,19 @@
  *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  *  POSSIBILITY OF SUCH DAMAGE.
  * 
- *  $Author: phaag $
- *
- *  $Id: nfsen.php 22 2007-11-20 12:27:38Z phaag $
- *
- *  $LastChangedRevision: 22 $
- *
  */
 
 // The very first function to call
 session_start();
 
-$expected_version = "1.3.8";
+$expected_version = "1.3.11";
 
 // Session check
 if ( array_key_exists('backend_version', $_SESSION ) && $_SESSION['backend_version'] !=  $expected_version ) {
 	session_destroy();
 	session_start();
 	$_SESSION['version'] = $expected_version;
-	print "<h1>Frontend - Backend version missmatch!</h1>\n";
+	print "<h1>Frontend - Backend version mismatch!</h1>\n";
 }
 
 include ("conf.php");
@@ -91,7 +85,8 @@ function SendHeader ($established) {
 
 	$_tab =  array_key_exists('tab', $_SESSION) ? $_SESSION['tab'] : 0;
 	if ( array_key_exists('tleft', $_SESSION ) ) {
-		$str = $TabList[$_tab] == 'Details' ? strftime("%b %d %Y - %H:%M", $_SESSION['tleft']) : 'Overview';
+		$datestr = date('M d Y - H:i T', $_SESSION['tleft']);
+    $str = $TabList[$_tab] == 'Details' ? $datestr : 'Overview';
 	} else {
 		$str = '';
 	}
@@ -163,7 +158,7 @@ function ReportLog($message) {
  *	"required" 	=> 1, 						, 0 or 1 must exists in $_POST, must not be NULL
  *	"allow_null"=> 1, 						, 0 or 1 allow value to be NULL
  *	"default"  	=> NULL, 					, if not exists or not defined use this default, maybe NULL
- *	"match" 	=> "/[^A-Za-z0-9\-+_]+/" 	, value must satify this reges, may be NULL
+ *	"match" 	=> "/[^A-Za-z0-9\-+_]+/" 	, value must satisfy this reges, may be NULL
  *	"validate" 	=> NULL),					, additional validate function to call for further processing, may be NULL
  */
 function ParseForm($parse_opts) {
@@ -348,9 +343,7 @@ function filter_validate(&$filter, $opts) {
 		return 0;
 	}
 
-	if (!get_magic_quotes_gpc()) {
-   		$filter = addslashes($filter);
-	}
+	$filter = addslashes($filter);
 	// $filter = escapeshellarg($filter);
 	$filter = explode("\n", $filter);
 	$opts = array();
@@ -373,11 +366,7 @@ function filter_validate(&$filter, $opts) {
 function description_validate(&$description, $opts) {
 
 	$_tmp = preg_replace("/\r/", '', $description);
-	if (!get_magic_quotes_gpc()) {
-   		$description = addslashes($_tmp);
-	} else {
-   		$description = $_tmp;
-	}
+	$description = addslashes($_tmp);
 	$description = explode("\n", $description);
 	return 0;
 
