@@ -146,9 +146,9 @@ ReportLog("nfsend EODATA");
 	$error_occured = 0;
 	while ( !$done ) {
 		if ( $is_binary ) 
-			$line = @socket_read($nfsend, 1024, PHP_BINARY_READ);
+			$line = @socket_read($nfsend, 65534, PHP_BINARY_READ);
 		else
-			$line = @socket_read($nfsend, 1024, PHP_NORMAL_READ);
+			$line = @socket_read($nfsend, 65534, PHP_NORMAL_READ);
 
 		if ( $line == FALSE ) {
 			$errno = socket_last_error($nfsend);
@@ -306,8 +306,9 @@ function UNIX2DISPLAY($time) {
 
 } // End of UNIX2DISPLAY
 
-function ScaleValue ( $value, $rateval ) {
+function ScaleValue ( $val, $rateval ) {
 
+	$value = intval($val);
 	if ( $rateval != 1 ) {
 		$value = $value / $rateval;
 		$rate_label = '/s';	// make bits
@@ -399,17 +400,17 @@ function SubdirHierarchy( $t ) {
 
 	$subdir_def = array (
 		"",
-		"%Y/%m/%d",
-		"%Y/%m/%d/%H",
-		"%Y/%W/%u",
-		"%Y/%W/%u/%H",
-		"%Y/%j",
-		"%Y/%j/%H",
-		"%Y-%m-%d",		# %F not supported by PHP
-		"%Y-%m-%d/%H"
+    "Y/m/d",
+    "Y/m/d/H",
+    "Y/W/l",
+    "Y/W/l/H",
+    "Y/z",
+    "Y/z/H",
+    "Y-m-d",
+    "Y-m-d/H",
 	);
 
-	return strftime ($subdir_def[$SUBDIRLAYOUT], $t);
+	return date ($subdir_def[$SUBDIRLAYOUT], $t);
 
 } // End of SubdirHierarchy
 
