@@ -307,7 +307,7 @@ function ProfileDialog ( ) {
 	if ( $_SESSION['profileinfo']['type'] == 0 ) {
 		$type = 'live';
 	} else {
-		$type  = ($_SESSION['profileinfo']['type'] & 3 ) == 2 ? "Continous" : "History";
+		$type  = ($_SESSION['profileinfo']['type'] & 3 ) == 2 ? "Continuous" : "History";
 		$type .= ($_SESSION['profileinfo']['type'] & 4) > 0  ? '&nbsp;/&nbsp;shadow' : '';
 	}
 
@@ -466,7 +466,7 @@ this, event, '200px')"><IMG SRC="icons/help.png" border="0" alt="help icon"></a>
 	<form style="display: inline;" name="profiletypeform" action="<?php  echo $self;?>"
 		onSubmit="return ConfirmNewType(<?php echo $current_type; ?>)" method="POST" >
 		<input type="radio" name="profile_type" value="2" <?php echo $current_type == 2 ? 'checked' : ''; ?>> 
-		Continous Profile<br>
+		Continuous Profile<br>
 <?php
 		$disable_mode = ( $current_type == 5 || $current_type == 6 ) ? 'disabled ' : '';
 ?>
@@ -475,12 +475,12 @@ this, event, '200px')"><IMG SRC="icons/help.png" border="0" alt="help icon"></a>
 		History Profile<br>
 		<hr class="hrule">
 		<input type="radio" name="profile_type" value="6" <?php echo $current_type == 6 ? 'checked' : ''; ?>> 
-		Continous Profile&nbsp;/&nbsp;shadow<br>
+		Continuous Profile&nbsp;/&nbsp;shadow<br>
 		<input type="radio" name="profile_type" value="5" <?php echo $current_type == 5 ? 'checked' : ''; ?>> 
 		History Profile&nbsp;/&nbsp;shadow<br>
 		<hr class="hrule">
 		<input name="edit" value="Commit new type" type="submit" >
-		<a href="#null" onMouseover="showhint('<b>Continous Profile</b><br>\
+		<a href="#null" onMouseover="showhint('<b>Continuous Profile</b><br>\
 Switching to a continuous profile starts profiling.<br>\
 <b>History Profile</b><br>Switching to a history profile stops profiling.<br> \
 <b>Shadow Profile</b><br>Switching to a shadow profile deletes all profiled netflow data to free disk space. \
@@ -590,8 +590,8 @@ Ex. 72, 72h, 4d 12h, 14days etc.', this, event, '200px')"><IMG SRC="icons/help.p
 		<input type="image" name="add_channel" value="add_channel" title="Add new channel" src="icons/plus.png" align="right">
 		</form>
 <?php } ?>
-		<a href="#null" onclick="ToggleAll('show')" id="all_r" title="expand channel list" <?php echo $style_arrow_right;?>><IMG SRC="icons/arrow.yellow.right.png" name="<?php echo $chan_id;?> right" border="0" alt="arrow right"></a>
-		<a href="#null" onclick="ToggleAll('hide')" id="all_d" title="collaps channel list"<?php echo $style_arrow_down;?>><IMG SRC="icons/arrow.yellow.down.png" name="<?php echo $chan_id;?> down" border="0" alt="arrow down"></a>	
+		<a href="#null" onclick="ToggleAll('show')" id="all_r" title="expand channel list" <?php echo $style_arrow_right;?>><IMG SRC="icons/arrow.yellow.right.png" name="arrow right" border="0" alt="arrow right"></a>
+		<a href="#null" onclick="ToggleAll('hide')" id="all_d" title="collapse channel list"<?php echo $style_arrow_down;?>><IMG SRC="icons/arrow.yellow.down.png" name="arrow down" border="0" alt="arrow down"></a>
 		Channel List:
 	</td>
 </tr>
@@ -631,6 +631,7 @@ function NewProfileDialog ($new_profile) {
 
 	$liveprofile = ReadProfile('./live');
 	$sources = array_keys($liveprofile['channel']); 
+	$selected_channel = array();
 
 	$live_start  = UNIX2DISPLAY($liveprofile['tstart']);
 	$tnow		 = time();
@@ -785,7 +786,7 @@ Ex. 72, 72h, 4d 12h, 14days etc. ', this, event, '200px')"><IMG SRC="icons/help.
 		<a href="#null" style="float:right;" onMouseover="showhint('<b>1:1 profile</b><br>\
 This is the classic NfSen profile where each selected input channel maps to a channel in the new profile. \
 All channels in the profile have the same filter.<br>\
-<b>individual channels</b><br>A profile may contain any number of independant channels, \
+<b>individual channels</b><br>A profile may contain any number of independent channels, \
 where each channel has it\'s own filter. The source for each channel can be any number of \
 input channels.', this, event, '200px')"><IMG SRC="icons/help.png" border="0" alt="help icon"></a>
 	</td>
@@ -1155,11 +1156,7 @@ function Process_stat_tab ($tab_changed, $profile_changed) {
 		
 		if ( array_key_exists('description', $_POST ) ) {
 			$_tmp = preg_replace("/\r/", '', $_POST['description']);
-			if (!get_magic_quotes_gpc()) {
-   				$description = addslashes($_tmp);
-			} else {
-   				$description = $_tmp;
-			}
+			$description = addslashes($_tmp);
 			$cmd_opts['description'] = explode("\n", $description);
 		}
 
@@ -1229,7 +1226,7 @@ function Process_stat_tab ($tab_changed, $profile_changed) {
 		return;
 	}
 		
-	// edit or add a channel? - process commited form entries
+	// edit or add a channel? - process committed form entries
 	if ( array_key_exists('edit_channel_commit', $_POST )   || array_key_exists('add_channel_commit', $_POST )) {
 
 		if ( array_key_exists('edit_channel_commit', $_POST ) )
@@ -1377,7 +1374,7 @@ function Process_stat_tab ($tab_changed, $profile_changed) {
 		return;
 	}
 
-	// create a new profile - process commited form
+	// create a new profile - process committed form
 	if ( array_key_exists('new_profile_commit', $_POST )) {
 
 		$parse_opts = array( 
@@ -1559,7 +1556,7 @@ function DisplayAdminPage() {
 
 			// setup channel defaults
 			if ( array_key_exists('form_data', $_SESSION ) ) {
-				// add channel contained errors - interate ones more
+				// add channel contained errors - iterate ones more
 				$channel_defaults = $_SESSION['form_data'];
 				unset($_SESSION['form_data']);
 				if ( $channel_defaults['sign'] == '+' ) {
