@@ -425,9 +425,9 @@ sub ReadStatInfo {
 	my $err = undef;
 	my $args;
 	if ( defined $tend ) {
-		$args = "-I -R $NfConf::PROFILEDATADIR/$profilepath/$channel/$subdirs/nfcapd.$tstart:nfcapd.$tend";
+		$args = "-I -G none -R $NfConf::PROFILEDATADIR/$profilepath/$channel/$subdirs/nfcapd.$tstart:nfcapd.$tend";
 	} else {
-		$args = "-I -r $NfConf::PROFILEDATADIR/$profilepath/$channel/$subdirs/nfcapd.$tstart";
+		$args = "-I -G none -r $NfConf::PROFILEDATADIR/$profilepath/$channel/$subdirs/nfcapd.$tstart";
 	}
 	local $SIG{CHLD} = 'DEFAULT';
 	if ( !open(NFDUMP, "$NfConf::PREFIX/nfdump $args 2>&1 |") ) {
@@ -557,7 +557,7 @@ sub GetPeakValues {
 
 		my $tiso = NfSen::UNIX2ISO($t);
 		foreach my $ch ( @AllChannels ) {
-			my $args = "-I -r $NfConf::PROFILEDATADIR/$profilepath/$ch/$subdirs/nfcapd.$tiso";
+			my $args = "-I -G none -r $NfConf::PROFILEDATADIR/$profilepath/$ch/$subdirs/nfcapd.$tiso";
 	
 			local $SIG{CHLD} = 'DEFAULT';
 			if ( !open(NFDUMP, "$NfConf::PREFIX/nfdump $args 2>&1 |") ) {
@@ -616,7 +616,7 @@ print ".Max+: $max_sum_pos at $iso_tpos, Max-: $max_sum_neg at $iso_tneg\n";
 
 
 #
-# Returns the profile info hash, if successfull
+# Returns the profile info hash, if successful
 # else returns EmptyProfile and sets Log::ERROR
 sub ReadProfile {
 	my $name  		 = shift;
@@ -692,7 +692,7 @@ sub ReadProfile {
 	}
 
 	if ( $profileinfo{'name'} ne $name ) {
-		$Log::ERROR = "Corrupt stat file. Needs to be rebuilded";
+		$Log::ERROR = "Corrupt stat file. Needs to be rebuilt";
 		return %empty;
 	}
 
@@ -708,7 +708,7 @@ sub ReadProfile {
 } # End of ReadProfile
 
 #
-# Returns the profile info hash, if successfull
+# Returns the profile info hash, if successful
 # else if already locked, return EmptyProfile with 'locked' = 1
 # else returns EmptyProfile and sets Log::ERROR
 sub LockProfile {
@@ -770,7 +770,7 @@ sub LockProfile {
 	if ( $profileinfo{'name'} ne $name ) {
 		flock ProFILE, LOCK_UN;
 		close ProFILE;
-		$Log::ERROR = "Corrupt stat file. Needs to be rebuilded";
+		$Log::ERROR = "Corrupt stat file. Needs to be rebuilt";
 		return %empty;
 	}
 
@@ -915,11 +915,10 @@ sub ProfileHistory {
 
 	my $profilepath = ProfilePath($name, $group);
 	my $subdirlayout = $NfConf::SUBDIRLAYOUT ? "-S $NfConf::SUBDIRLAYOUT" : "";
-	my $arg = "-I -p $NfConf::PROFILEDATADIR -P $NfConf::PROFILESTATDIR $subdirlayout ";
-	$arg   .= "-z " if $NfConf::ZIPprofiles;
+	my $arg = "-I $NfConf::ZIPprofiles -p $NfConf::PROFILEDATADIR -P $NfConf::PROFILESTATDIR $subdirlayout ";
 
 	# create argument list specific for each channel
-	# at the moment this contains of all channels in a continues profile
+	# at the moment this contains of all channels in a continuous profile
 	my @ProfileOptList;
 	foreach my $channel ( keys %{$$profileref{'channel'}} ) {
 		push @ProfileOptList, "$group#$name#$$profileref{'type'}#$channel#$$profileref{'channel'}{$channel}{'sourcelist'}";
@@ -1247,7 +1246,7 @@ sub DoRebuild {
 
 	} else {
 		if ( $$profileinfo{'name'} ne $profile ) {
-			syslog("warning", "Profile name missmatch - Set '$$profileinfo{'name'}' to '$profile'");
+			syslog("warning", "Profile name mismatch - Set '$$profileinfo{'name'}' to '$profile'");
 			$$profileinfo{'name'} 	= $profile;
 			$$profileinfo{'group'}	= $profilegroup;
 		}
@@ -1351,14 +1350,14 @@ sub DoRebuild {
 		}
 
 		# history data is updated and we are done with history profiles
-		# A continous profile except 'live' must be updated up to the current slot 
+		# A continuous profile except 'live' must be updated up to the current slot 
 		# rebuilding the profile could have missed new slots -> profile missing slots
 		if ( $continous_profile && ($profile ne 'live' || $profilegroup ne '.') ) {
 			# get current current time slot
 			my %liveprofile = ReadProfile('live', '.');
 			$tend = $liveprofile{'tend'};
 
-			# this can happen, if a history profile is switch back to continous
+			# this can happen, if a history profile is switch back to continuous
 			# profile and wants to get updated now. Be sure we have all data
 			if ( $t < $liveprofile{'tstart'} ) {
 				$t = $liveprofile{'tstart'};
@@ -1372,8 +1371,7 @@ sub DoRebuild {
 			}
 			my $channellist = join ':', keys %{$liveprofile{'channel'}};
 			my $subdirlayout = $NfConf::SUBDIRLAYOUT ? "-S $NfConf::SUBDIRLAYOUT" : "";
-			my $arg = "-I -p $NfConf::PROFILEDATADIR -P $NfConf::PROFILESTATDIR $subdirlayout ";
-			$arg   .= "-z " if $NfConf::ZIPprofiles;
+			my $arg = "-I $NfConf::ZIPprofiles -p $NfConf::PROFILEDATADIR -P $NfConf::PROFILESTATDIR $subdirlayout ";
 
 			# profile missing slots
 			if ( $t <= $tend ) {
@@ -1426,7 +1424,7 @@ sub DoRebuild {
 			}
 		}
 	} else {
-		syslog('info', "Graphs for profile '$profile', group '$profilegroup' not rebuilded");
+		syslog('info', "Graphs for profile '$profile', group '$profilegroup' not rebuilt");
 	}
 
 	if ( $profile eq 'live' && $profilegroup eq '.' ) {
@@ -1671,7 +1669,7 @@ sub AddProfile {
 	my $opts   = shift;
 
 	# both options can be set at the same time
-	my $history_profile	= 0;	# Profile start back in time; needs to be builded
+	my $history_profile	= 0;	# Profile start back in time; needs to be rebuilt
 	my $continuous_profile = 0;	# Profile continuous in time
 	
 	my ($profile, $profilegroup);
@@ -1839,7 +1837,7 @@ sub AddProfile {
 	# the first slot to be updated is 'updated' + $NfConf::CYCLETIME
 	$profileinfo{'updated'}		= $tstart - $NfConf::CYCLETIME;	
 
-	# expiring profiles makes only sense for continous profiles
+	# expiring profiles makes only sense for continuous profiles
 	$profileinfo{'expire'} 		= $continuous_profile ? $lifetime : 0;
 	$profileinfo{'maxsize'} 	= $continuous_profile ? $maxsize : 0;
 
@@ -2410,7 +2408,7 @@ sub CommitProfile {
 			return;
 		}
 		if ( $pid ) { 
-			# we are the parent processs
+			# we are the parent process
 			print $socket "pid=$pid\n";
 			print $socket $EODATA;
 			print $socket "OK Profiling netflow data\n";
@@ -2958,7 +2956,7 @@ sub RebuildProfile {
 		print $socket "ERR $status\n";
 
 	} else {
-		print $socket "OK profile rebuilded\n";
+		print $socket "OK profile rebuilt\n";
 	}
 
 } # End of RebuildProfile
@@ -3441,8 +3439,8 @@ sub CheckProfiles {
 				} else {
 					$profileinfo{'type'} = 1;
 				}
-				my $status = DoRebuild(\%profileinfo, $profile, $profilegroup, $profilepath, 0, 0);
-				syslog('err', "Rebuilded profile '$profile' in group '$profilegroup': $status ");
+				my $status = DoRebuild(*STDOUT, \%profileinfo, $profile, $profilegroup, $profilepath, 0, 0);
+				syslog('err', "Rebuilt profile '$profile' in group '$profilegroup': $status ");
 			}
 			if ( -f "$NfConf::PROFILESTATDIR/$profilepath/.CANCELED" ) {
 				syslog('err', "Clean-up debris profile '$profile' in group '$profilegroup' ");
@@ -3453,8 +3451,8 @@ sub CheckProfiles {
 				} else {
 					$profileinfo{'type'} = 1;
 				}
-				my $status = DoRebuild(\%profileinfo, $profile, $profilegroup, $profilepath, 0, 0);
-				syslog('err', "Rebuilded profile '$profile' in group '$profilegroup': $status ");
+				my $status = DoRebuild(*STDOUT, \%profileinfo, $profile, $profilegroup, $profilepath, 0, 0);
+				syslog('err', "Rebuilt profile '$profile' in group '$profilegroup': $status ");
 			}
 			if ( $profileinfo{'locked'} ) {
 				syslog('err', "Clean-up debris profile '$profile' in group '$profilegroup' ");
