@@ -1,5 +1,6 @@
 #!/usr/bin/perl
 #
+#  Copyright (c) 2022, Peter Haag
 #  Copyright (c) 2004, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
 #  All rights reserved.
 #
@@ -27,17 +28,13 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: peter $
-#
-#  $Id: NfSenRRD.pm 72 2017-01-22 13:04:08Z peter $
-#
-#  $LastChangedRevision: 72 $
 
 package NfSenRRD;
 
 use RRDs;
 use Log;
 use NfSen;
+use File::Temp qw/tempfile/;
 use strict;
 use warnings;
 
@@ -73,7 +70,7 @@ sub GetRRDoffset {
 	if ( $rrd_version < 1.1 ) { # it's RRD 1.0.x
 		$RRDoffset = 77;
 	}
-	if ( $rrd_version >= 1.2 && $rrd_version < 1.6 ) {
+	if ( $rrd_version >= 1.2 && $rrd_version < 1.9 ) {
 		$RRDoffset = 67;
 	}
 
@@ -284,7 +281,7 @@ sub GenGraph {
 	}
 
 	my $graph_filename = "$NfConf::PROFILESTATDIR/$profiledir/${what}${extension}.png";
-	my ($averages,$xsize,$ysize) = RRDs::graph $graph_filename,
+	my $res = RRDs::graphv $graph_filename,
 		@DEFS,
 		"--imgformat", "PNG",
 		"--title", 			"$title" ,
@@ -386,7 +383,7 @@ sub GenDetailsGraph {
 	my $tleft   	= shift @{$detailargs};	# left time of marker - UNIX format; 0 is no marker
 	my $tright  	= shift @{$detailargs};	# right time of marker - UNIX format; 0 is no marker
 	my $width		= shift @{$detailargs};	# width of graph
-	my $heigh		= shift @{$detailargs};	# heigh of graph
+	my $heigh		= shift @{$detailargs};	# height of graph
 	my $light		= shift @{$detailargs};	# light version ( small graphs ) - no title no span window
 	my $logscale	= shift @{$detailargs};	# linear or log y-Axis
 	my $linegraph	= shift @{$detailargs};	# linear or log y-Axis
@@ -451,7 +448,9 @@ sub GenDetailsGraph {
 	}
 
 	my @rrdargs = ();
-	push @rrdargs, "-";	# output graphics to stdout
+	#push @rrdargs, "-";	# output graphics to stdout
+	my (undef,$tmpng) = tempfile('/tmp/NfProfilePNGXXXX',OPEN => 0) or die "Unable to create tempfile";
+        push @rrdargs, $tmpng;  # output graphics to temp file
 
 	foreach my $def ( @DEFS ) {
 		$$profileinfo{'channel'}{$def}{'scale'} = $$profileinfo{'channel'}{$def}{'sign'} eq "-" ? -1 : 1;
@@ -527,6 +526,8 @@ sub GenDetailsGraph {
 		SendFile("$NfConf::HTMLDIR/icons/ErrorGraph.png");
 		return "$ERROR: Arg: '$profile', '$sources', '$proto', '$type', '$pstart', '$tstart', '$tend', '$tleft', '$tright', '$width', '$heigh', '$light', '$logscale', '$linegraph'";
 	} else {
+		SendFile($tmpng);
+                unlink($tmpng);
 		return "ok";
 	}
 
@@ -567,7 +568,9 @@ sub GenAlertGraph {
 	my @DEFS = split ':', $sources;
 	
 	my @rrdargs = ();
-	push @rrdargs, "-";	# output graphics to stdout
+	#push @rrdargs, "-";	# output graphics to stdout
+	my (undef,$tmpng) = tempfile('/tmp/NfProfilePNGXXXX',OPEN => 0) or die "Unable to create tempfile";
+        push @rrdargs, $tmpng;  # output graphics to temp file
 
 	foreach my $def ( @DEFS ) {
 		push @rrdargs, "DEF:data${def}=$NfConf::PROFILESTATDIR/~$alertname/avg-$type.rrd:${def}:AVERAGE";
@@ -604,6 +607,8 @@ sub GenAlertGraph {
 		SendFile("$NfConf::HTMLDIR/icons/ErrorGraph.png");
 		return "ERR failed $ERROR";
 	} else {
+		SendFile($tmpng);
+                unlink($tmpng);
 		return "ok";
 	}
 
